nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Dllcr

Struct Dllcr 

#[repr(transparent)]
pub struct Dllcr(pub u32);
DLL Control Register 0

Tuple Fields

0: u32

Implementations

Source

impl Dllcr

pub const fn dllen(&self) -> bool

DLL calibration enable.

pub const fn set_dllen(&mut self, val: bool)

DLL calibration enable.

pub const fn dllreset(&self) -> bool

DLL reset

pub const fn set_dllreset(&mut self, val: bool)

DLL reset

pub const fn slvdlytarget(&self) -> u8

The delay target for slave delay line is: ((SLVDLYTARGET+1) * 1/32 * clock cycle of reference clock (serial root clock). If serial root clock is >= 100 MHz, DLLEN set to 0x1, OVRDEN set to =0x0, then SLVDLYTARGET setting of 0xF is recommended.

pub const fn set_slvdlytarget(&mut self, val: u8)

The delay target for slave delay line is: ((SLVDLYTARGET+1) * 1/32 * clock cycle of reference clock (serial root clock). If serial root clock is >= 100 MHz, DLLEN set to 0x1, OVRDEN set to =0x0, then SLVDLYTARGET setting of 0xF is recommended.

pub const fn ovrden(&self) -> bool

Slave clock delay line delay cell number selection override enable.

pub const fn set_ovrden(&mut self, val: bool)

Slave clock delay line delay cell number selection override enable.

pub const fn ovrdval(&self) -> u8

Slave clock delay line delay cell number selection override value.

pub const fn set_ovrdval(&mut self, val: u8)

Slave clock delay line delay cell number selection override value.