nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Flshcr1

Struct Flshcr1 

#[repr(transparent)]
pub struct Flshcr1(pub u32);
Flash Control Register 1

Tuple Fields

0: u32

Implementations

Source

impl Flshcr1

pub const fn tcss(&self) -> u8

Serial Flash CS setup time.

pub const fn set_tcss(&mut self, val: u8)

Serial Flash CS setup time.

pub const fn tcsh(&self) -> u8

Serial Flash CS Hold time.

pub const fn set_tcsh(&mut self, val: u8)

Serial Flash CS Hold time.

pub const fn wa(&self) -> bool

Word Addressable.

pub const fn set_wa(&mut self, val: bool)

Word Addressable.

pub const fn cas(&self) -> u8

Column Address Size.

pub const fn set_cas(&mut self, val: u8)

Column Address Size.

pub const fn csintervalunit(&self) -> Csintervalunit

CS interval unit

pub const fn set_csintervalunit(&mut self, val: Csintervalunit)

CS interval unit

pub const fn csinterval(&self) -> u16

This field is used to set the minimum interval between flash device chip select deassertion and flash device chip select assertion. If external flash has a limitation on the interval between command sequences, this field should be set accordingly. If there is no limitation, set this field with value 0x0.

pub const fn set_csinterval(&mut self, val: u16)

This field is used to set the minimum interval between flash device chip select deassertion and flash device chip select assertion. If external flash has a limitation on the interval between command sequences, this field should be set accordingly. If there is no limitation, set this field with value 0x0.