#[repr(transparent)]pub struct Flshcr2(pub u32);Expand description
Flash Control Register 2
Tuple Fields
0: u32Implementations
Sourceimpl Flshcr2
impl Flshcr2
Sourcepub const fn set_ardseqid(&mut self, val: u8)
pub const fn set_ardseqid(&mut self, val: u8)
Sequence Index for AHB Read triggered Command in LUT.
Sourcepub const fn set_ardseqnum(&mut self, val: u8)
pub const fn set_ardseqnum(&mut self, val: u8)
Sequence Number for AHB Read triggered Command in LUT.
Sourcepub const fn set_awrseqid(&mut self, val: u8)
pub const fn set_awrseqid(&mut self, val: u8)
Sequence Index for AHB Write triggered Command.
Sourcepub const fn set_awrseqnum(&mut self, val: u8)
pub const fn set_awrseqnum(&mut self, val: u8)
Sequence Number for AHB Write triggered Command.
Sourcepub const fn awrwait(&self) -> u16
pub const fn awrwait(&self) -> u16
For certain devices (such as FPGA), it need some time to write data into internal memory after the command sequences finished on FlexSPI interface. If another Read command sequence comes before previous programming finished internally, the read data may be wrong. This field is used to hold AHB Bus ready for AHB write access to wait the programming finished in external device. Then there will be no AHB read command triggered before the programming finished in external device. The Wait cycle between AHB triggered command sequences finished on FlexSPI interface and AHB return Bus ready: AWRWAIT * AWRWAITUNIT
Sourcepub const fn set_awrwait(&mut self, val: u16)
pub const fn set_awrwait(&mut self, val: u16)
For certain devices (such as FPGA), it need some time to write data into internal memory after the command sequences finished on FlexSPI interface. If another Read command sequence comes before previous programming finished internally, the read data may be wrong. This field is used to hold AHB Bus ready for AHB write access to wait the programming finished in external device. Then there will be no AHB read command triggered before the programming finished in external device. The Wait cycle between AHB triggered command sequences finished on FlexSPI interface and AHB return Bus ready: AWRWAIT * AWRWAITUNIT
Sourcepub const fn awrwaitunit(&self) -> Awrwaitunit
pub const fn awrwaitunit(&self) -> Awrwaitunit
AWRWAIT unit
Sourcepub const fn set_awrwaitunit(&mut self, val: Awrwaitunit)
pub const fn set_awrwaitunit(&mut self, val: Awrwaitunit)
AWRWAIT unit
Sourcepub const fn clrinstrptr(&self) -> bool
pub const fn clrinstrptr(&self) -> bool
Clear the instruction pointer which is internally saved pointer by JMP_ON_CS.
Sourcepub const fn set_clrinstrptr(&mut self, val: bool)
pub const fn set_clrinstrptr(&mut self, val: bool)
Clear the instruction pointer which is internally saved pointer by JMP_ON_CS.