nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Inten

Struct Inten 

#[repr(transparent)]
pub struct Inten(pub u32);
Interrupt Enable Register

Tuple Fields

0: u32

Implementations

Source

impl Inten

pub const fn ipcmddoneen(&self) -> bool

IP triggered Command Sequences Execution finished interrupt enable.

pub const fn set_ipcmddoneen(&mut self, val: bool)

IP triggered Command Sequences Execution finished interrupt enable.

pub const fn ipcmdgeen(&self) -> bool

IP triggered Command Sequences Grant Timeout interrupt enable.

pub const fn set_ipcmdgeen(&mut self, val: bool)

IP triggered Command Sequences Grant Timeout interrupt enable.

pub const fn ahbcmdgeen(&self) -> bool

AHB triggered Command Sequences Grant Timeout interrupt enable.

pub const fn set_ahbcmdgeen(&mut self, val: bool)

AHB triggered Command Sequences Grant Timeout interrupt enable.

pub const fn ipcmderren(&self) -> bool

IP triggered Command Sequences Error Detected interrupt enable.

pub const fn set_ipcmderren(&mut self, val: bool)

IP triggered Command Sequences Error Detected interrupt enable.

pub const fn ahbcmderren(&self) -> bool

AHB triggered Command Sequences Error Detected interrupt enable.

pub const fn set_ahbcmderren(&mut self, val: bool)

AHB triggered Command Sequences Error Detected interrupt enable.

pub const fn iprxwaen(&self) -> bool

IP RX FIFO WaterMark available interrupt enable.

pub const fn set_iprxwaen(&mut self, val: bool)

IP RX FIFO WaterMark available interrupt enable.

pub const fn iptxween(&self) -> bool

IP TX FIFO WaterMark empty interrupt enable.

pub const fn set_iptxween(&mut self, val: bool)

IP TX FIFO WaterMark empty interrupt enable.

pub const fn sckstopbyrden(&self) -> bool

SCLK is stopped during command sequence because Async RX FIFO full interrupt enable.

pub const fn set_sckstopbyrden(&mut self, val: bool)

SCLK is stopped during command sequence because Async RX FIFO full interrupt enable.

pub const fn sckstopbywren(&self) -> bool

SCLK is stopped during command sequence because Async TX FIFO empty interrupt enable.

pub const fn set_sckstopbywren(&mut self, val: bool)

SCLK is stopped during command sequence because Async TX FIFO empty interrupt enable.

pub const fn ahbbustimeouten(&self) -> bool

AHB Bus timeout interrupt.

pub const fn set_ahbbustimeouten(&mut self, val: bool)

AHB Bus timeout interrupt.

pub const fn seqtimeouten(&self) -> bool

Sequence execution timeout interrupt enable.

pub const fn set_seqtimeouten(&mut self, val: bool)

Sequence execution timeout interrupt enable.