nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Mcr0

Struct Mcr0 

#[repr(transparent)]
pub struct Mcr0(pub u32);
Module Control Register 0

Tuple Fields

0: u32

Implementations

Source

impl Mcr0

pub const fn swreset(&self) -> bool

Software Reset

pub const fn set_swreset(&mut self, val: bool)

Software Reset

pub const fn mdis(&self) -> bool

Module Disable

pub const fn set_mdis(&mut self, val: bool)

Module Disable

pub const fn rxclksrc(&self) -> Rxclksrc

Sample Clock source selection for Flash Reading

pub const fn set_rxclksrc(&mut self, val: Rxclksrc)

Sample Clock source selection for Flash Reading

pub const fn ardfen(&self) -> Ardfen

Enable AHB bus Read Access to IP RX FIFO.

pub const fn set_ardfen(&mut self, val: Ardfen)

Enable AHB bus Read Access to IP RX FIFO.

pub const fn atdfen(&self) -> Atdfen

Enable AHB bus Write Access to IP TX FIFO.

pub const fn set_atdfen(&mut self, val: Atdfen)

Enable AHB bus Write Access to IP TX FIFO.

pub const fn serclkdiv(&self) -> Serclkdiv

Serial root clock

pub const fn set_serclkdiv(&mut self, val: Serclkdiv)

Serial root clock

pub const fn hsen(&self) -> Hsen

Half Speed Serial Flash Access Enable.

pub const fn set_hsen(&mut self, val: Hsen)

Half Speed Serial Flash Access Enable.

pub const fn dozeen(&self) -> Dozeen

Doze mode enable bit

pub const fn set_dozeen(&mut self, val: Dozeen)

Doze mode enable bit

pub const fn combinationen(&self) -> bool

This bit is to support Flash Octal mode access by combining Port A and B Data pins (A_DATA[3:0] and B_DATA[3:0]), when Port A and Port B are of 4 bit data width.

pub const fn set_combinationen(&mut self, val: bool)

This bit is to support Flash Octal mode access by combining Port A and B Data pins (A_DATA[3:0] and B_DATA[3:0]), when Port A and Port B are of 4 bit data width.

pub const fn sckfreerunen(&self) -> bool

This bit is used to enable SCLK output free-running. For FPGA applications, the external device may use SCLK as reference clock to its internal PLL.

pub const fn set_sckfreerunen(&mut self, val: bool)

This bit is used to enable SCLK output free-running. For FPGA applications, the external device may use SCLK as reference clock to its internal PLL.

pub const fn ipgrantwait(&self) -> u8

Timeout wait cycle for IP command grant.

pub const fn set_ipgrantwait(&mut self, val: u8)

Timeout wait cycle for IP command grant.

pub const fn ahbgrantwait(&self) -> u8

Timeout wait cycle for AHB command grant.

pub const fn set_ahbgrantwait(&mut self, val: u8)

Timeout wait cycle for AHB command grant.