nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Mcr1

Struct Mcr1 

#[repr(transparent)]
pub struct Mcr1(pub u32);
Module Control Register 1

Tuple Fields

0: u32

Implementations

Source

impl Mcr1

pub const fn ahbbuswait(&self) -> u16

AHB Bus wait

pub const fn set_ahbbuswait(&mut self, val: u16)

AHB Bus wait

pub const fn seqwait(&self) -> u16

Command Sequence Execution will timeout and abort after SEQWAIT * 1024 Serial Root Clock cycles. When sequence execution timeout occurs, there will be an interrupt generated (INTR[SEQTIMEOUT]) if this interrupt is enabled (INTEN[SEQTIMEOUTEN] is set 0x1) and AHB command is ignored by arbitrator.

pub const fn set_seqwait(&mut self, val: u16)

Command Sequence Execution will timeout and abort after SEQWAIT * 1024 Serial Root Clock cycles. When sequence execution timeout occurs, there will be an interrupt generated (INTR[SEQTIMEOUT]) if this interrupt is enabled (INTEN[SEQTIMEOUTEN] is set 0x1) and AHB command is ignored by arbitrator.