nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Sts0

Struct Sts0 

#[repr(transparent)]
pub struct Sts0(pub u32);
Status Register 0

Tuple Fields

0: u32

Implementations

Source

impl Sts0

pub const fn seqidle(&self) -> bool

This status bit indicates the state machine in SEQ_CTL is idle and there is command sequence executing on FlexSPI interface.

pub const fn set_seqidle(&mut self, val: bool)

This status bit indicates the state machine in SEQ_CTL is idle and there is command sequence executing on FlexSPI interface.

pub const fn arbidle(&self) -> bool

This status bit indicates the state machine in ARB_CTL is busy and there is command sequence granted by arbitrator and not finished yet on FlexSPI interface. When ARB_CTL state (ARBIDLE=0x1) is idle, there will be no transaction on FlexSPI interface also (SEQIDLE=0x1). So this bit should be polled to wait for FlexSPI controller become idle instead of SEQIDLE.

pub const fn set_arbidle(&mut self, val: bool)

This status bit indicates the state machine in ARB_CTL is busy and there is command sequence granted by arbitrator and not finished yet on FlexSPI interface. When ARB_CTL state (ARBIDLE=0x1) is idle, there will be no transaction on FlexSPI interface also (SEQIDLE=0x1). So this bit should be polled to wait for FlexSPI controller become idle instead of SEQIDLE.

pub const fn arbcmdsrc(&self) -> Arbcmdsrc

This status field indicates the trigger source of current command sequence granted by arbitrator. This field value is meaningless when ARB_CTL is not busy (STS0[ARBIDLE]=0x1).

pub const fn set_arbcmdsrc(&mut self, val: Arbcmdsrc)

This status field indicates the trigger source of current command sequence granted by arbitrator. This field value is meaningless when ARB_CTL is not busy (STS0[ARBIDLE]=0x1).