#[repr(transparent)]pub struct Flshcr1(pub u32);Expand description
Flash Control Register 1
Tuple Fields
0: u32Implementations
Sourceimpl Flshcr1
impl Flshcr1
Sourcepub const fn csintervalunit(&self) -> Csintervalunit
pub const fn csintervalunit(&self) -> Csintervalunit
CS interval unit
Sourcepub const fn set_csintervalunit(&mut self, val: Csintervalunit)
pub const fn set_csintervalunit(&mut self, val: Csintervalunit)
CS interval unit
Sourcepub const fn csinterval(&self) -> u16
pub const fn csinterval(&self) -> u16
This field is used to set the minimum interval between flash device chip select deassertion and flash device chip select assertion. If external flash has a limitation on the interval between command sequences, this field should be set accordingly. If there is no limitation, set this field with value 0x0.
Sourcepub const fn set_csinterval(&mut self, val: u16)
pub const fn set_csinterval(&mut self, val: u16)
This field is used to set the minimum interval between flash device chip select deassertion and flash device chip select assertion. If external flash has a limitation on the interval between command sequences, this field should be set accordingly. If there is no limitation, set this field with value 0x0.