#[repr(transparent)]pub struct Mcr1(pub u32);Expand description
Module Control Register 1
Tuple Fields
0: u32Implementations
Sourceimpl Mcr1
impl Mcr1
Sourcepub const fn ahbbuswait(&self) -> u16
pub const fn ahbbuswait(&self) -> u16
AHB Bus wait
Sourcepub const fn set_ahbbuswait(&mut self, val: u16)
pub const fn set_ahbbuswait(&mut self, val: u16)
AHB Bus wait
Sourcepub const fn seqwait(&self) -> u16
pub const fn seqwait(&self) -> u16
Command Sequence Execution will timeout and abort after SEQWAIT * 1024 Serial Root Clock cycles. When sequence execution timeout occurs, there will be an interrupt generated (INTR[SEQTIMEOUT]) if this interrupt is enabled (INTEN[SEQTIMEOUTEN] is set 0x1) and AHB command is ignored by arbitrator.
Sourcepub const fn set_seqwait(&mut self, val: u16)
pub const fn set_seqwait(&mut self, val: u16)
Command Sequence Execution will timeout and abort after SEQWAIT * 1024 Serial Root Clock cycles. When sequence execution timeout occurs, there will be an interrupt generated (INTR[SEQTIMEOUT]) if this interrupt is enabled (INTEN[SEQTIMEOUTEN] is set 0x1) and AHB command is ignored by arbitrator.